@@ -26,7 +26,8 @@ function(response, x, boot.n.c=10, boost.steps=100,
       } else {
       w.quantile <- 90
       space <- round(length(time[uncens])/100)
-      w.eval.times.c <- c(0,sort(time[uncens])[(1:w.quantile)*space])
+      index <- (1:w.quantile)*space
+      w.eval.times.c <- c(0,sort(time[uncens])[index[index<length(time[uncens])]])
       }
    } else {
       w.eval.times.c <- sort(eval.times)
